<?php
/**
 * Class ProductPageCalculatorInfo
 */

namespace Octolize\Shipping\CostOnProductPage;

use OctolizeShippingCostOnProductPageVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use WC_Countries;
use WC_Customer;

/**
 * Add calculator
 */
class ProductPageCalculatorInfo implements Hookable {

	/**
	 * @var WC_Customer
	 */
	private $customer;

	/**
	 * @var WC_Countries
	 */
	private $countries;

	/**
	 * @var PluginSettings
	 */
	private $plugin_settings;

	/**
	 * @param PluginSettings $plugin_settings .
	 * @param WC_Customer    $customer        .
	 * @param WC_Countries   $countries       .
	 */
	public function __construct( PluginSettings $plugin_settings, WC_Customer $customer, WC_Countries $countries ) {
		$this->customer        = $customer;
		$this->countries       = $countries;
		$this->plugin_settings = $plugin_settings;
	}

	/**
	 * @return void
	 */
	public function hooks(): void {
		add_action( $this->plugin_settings->get_calculator_location(), [ $this, 'render_container' ] );
	}

	/**
	 * @return void
	 */
	public function render_container(): void {
		if ( ! $this->plugin_settings->is_enabled() ) {
			return;
		}

		wp_enqueue_style( Assets::HANDLE );
		wp_enqueue_script( Assets::HANDLE );

		$customer  = $this->customer;
		$countries = $this->countries;

		include __DIR__ . '/views/html-shipping-calculator.php';
	}
}
