<?php
/**
 * Class ShippingCalculator
 */

namespace Octolize\Shipping\CostOnProductPage;

use Exception;
use WC_Cart;
use WC_Shipping;
use WC_Shipping_Rate;
use WC_Shortcode_Cart;

/**
 * .
 */
class ShippingCalculator {

	/**
	 * @var WC_Cart
	 */
	private $cart;

	/**
	 * @var WC_Shipping
	 */
	private $shipping;

	/**
	 * @param WC_Cart     $cart     .
	 * @param WC_Shipping $shipping .
	 */
	public function __construct( WC_Cart $cart, WC_Shipping $shipping ) {
		$this->cart     = $cart;
		$this->shipping = $shipping;
	}

	/**
	 * @param CreatorShippingPackages $creator_shipping_packages
	 *
	 * @return void
	 * @throws Exception
	 * @codeCoverageIgnore
	 */
	public function calculate( CreatorShippingPackages $creator_shipping_packages ): void {
		// Upgrade settings.
		$this->calculate_shipping();

		// Calculate totals before.
		$this->cart->calculate_totals();

		// Calculate current cart.
		$this->shipping->calculate_shipping( $creator_shipping_packages->get_shipping_packages() );
	}

	/**
	 * @return WC_Shipping_Rate[]
	 */
	public function get_rates(): array {
		// Filter packages.
		$packages = array_values(
			array_filter(
				$this->shipping->get_packages(),
				function ( array $package ) {
					return is_array( $package['rates'] ?? null ) && ! empty( $package['rates'] );
				}
			)
		);

		$rates = [];

		foreach ( $packages as $package ) {
			foreach ( $package['rates'] as $rate ) {
				$rates[] = $rate;
			}
		}

		return $rates;
	}

	/**
	 * @return void
	 * @throws Exception
	 * @codeCoverageIgnore
	 */
	protected function calculate_shipping(): void {
		WC_Shortcode_Cart::calculate_shipping();
	}
}
